/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "certificatecontainer.hxx"
#include <cppuhelper/supportsservice.hxx>

#include <sal/config.h>

using namespace ::com::sun::star;
using namespace ::com::sun::star::lang;
using namespace ::com::sun::star::uno;

bool
CertificateContainer::searchMap( const OUString & url, const OUString & certificate_name, Map &_certMap )
{
    Map::iterator p = _certMap.find(url);

    bool ret = false;

    while( p != _certMap.end() )
    {
        ret = (*p).second == certificate_name;
        if( ret )
                    break;
        ++p;
    }

    return ret;
}

bool
CertificateContainer::isTemporaryCertificate ( const OUString & url, const OUString & certificate_name )
{
    return searchMap( url, certificate_name, certMap);
}

bool
CertificateContainer::isCertificateTrust ( const OUString & url, const OUString & certificate_name )
{
    return searchMap( url, certificate_name, certTrustMap);
}

sal_Bool
CertificateContainer::addCertificate( const OUString & url, const OUString & certificate_name, sal_Bool trust )
{
    certMap.emplace( url, certificate_name );

        //remember that the cert is trusted
        if (trust)
            certTrustMap.emplace( url, certificate_name );

        return true;
}

::security::CertificateContainerStatus
CertificateContainer::hasCertificate( const OUString & url, const OUString & certificate_name )
{
    if ( isTemporaryCertificate( url, certificate_name ) )
    {
        if ( isCertificateTrust( url, certificate_name ) )
            return security::CertificateContainerStatus( security::CertificateContainerStatus_TRUSTED );
        else
            return security::CertificateContainerStatus_UNTRUSTED;
    } else
    {
        return security::CertificateContainerStatus_NOCERT;
    }
}

OUString SAL_CALL
CertificateContainer::getImplementationName( )
{
    return impl_getStaticImplementationName();
}

sal_Bool SAL_CALL
CertificateContainer::supportsService( const OUString& ServiceName )
{
    return cppu::supportsService( this, ServiceName );
}

Sequence< OUString > SAL_CALL
CertificateContainer::getSupportedServiceNames(  )
{
    return impl_getStaticSupportedServiceNames();
}

Sequence< OUString > SAL_CALL
CertificateContainer::impl_getStaticSupportedServiceNames(  )
{
    Sequence< OUString > aRet { "com.sun.star.security.CertificateContainer" };
    return aRet;
}

OUString SAL_CALL
CertificateContainer::impl_getStaticImplementationName()
{
    return OUString("com.sun.star.security.CertificateContainer");
}

Reference< XInterface > SAL_CALL CertificateContainer::impl_createInstance( const Reference< XMultiServiceFactory >& xServiceManager )
{
    return Reference< XInterface >( *new CertificateContainer( xServiceManager ) );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
